@@ -24,11 +24,11 @@ Net::API::Gett - Perl bindings for Ge.tt API
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =cut
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 =head1 SYNOPSIS
 
@@ -50,7 +50,7 @@ our $VERSION = '1.02';
         encoding => ":encoding(UTF-8)" 
     );
 
-    say "File has been shared at " . $file_obj->url;
+    say "File has been shared at " . $file_obj->getturl;
 
     # Download contents
     my $file_contents = $file_obj->contents();
@@ -427,6 +427,7 @@ sub _build_share {
         sharename => $share_href->{'sharename'},
         created => $share_href->{'created'},
         title => $share_href->{'title'},
+        getturl => $share_href->{'getturl'},
     );
     foreach my $file_href ( @{ $share_href->{'files'} } ) {
         next unless $file_href;
@@ -444,7 +445,7 @@ sub _build_file {
 
     # filter out undefined attributes
     my @attrs = grep { defined $file_href->{$_} } 
-        qw(filename size created fileid downloads readystate url download sharename);
+        qw(filename size created fileid downloads readystate getturl download sharename);
     my @params = map { $_ => $file_href->{$_} } @attrs;
 
     if ( exists $file_href->{'upload'} ) {
